#ifndef _SYSPLAYER_H_
#define _SYSPLAYER_H_

#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
#include <fcntl.h>
#include <sys/types.h>   /* added */
#include <sys/socket.h>  /*      */
#include <netinet/in.h>     /*      */
#include <arpa/inet.h>  
#include <dmedia/dmedia.h>
#include <dmedia/cl.h>
#include <audio.h>
#include <audiofile.h>

#include "sc.h"
#include "vodSGI.h"

#define fileIORequest 0
#define networkIORequest 1
/* The standard ports used by the video server */
#define DATA_PORT_SERVER 2005
#define COMMAND_PORT_SERVER 2006
#define DATA_CONNECTION 0
#define COMMAND_CONNECTION 1

/* Client defines. */
#define readFromNetwork 50
#define networkReadOneFrame 51
#define decompressVideoFrames 52
#define decompressOneVideoFrame 53
#define decompressAudioFrames 54
#define decompressOneAudioFrame 55

typedef struct times{
  double sec;
  double msec;
  double usec;
}times;

typedef struct MpegPlay {
    char         *filename;                    /* input filename */
    FILE         *fp;                          /* file descriptor */
    unsigned long fileOffset;
    unsigned char EndOfFile;

    /* Image Characteristics */
    int           width;                      /* Image Width */
    int           height;                     /* Image Height */
    float         frameRate;                  /* Movie Frame rate (ignored) */
    int           frameSize;                  /* width * height * 4 */
    int           totalFrames;

    /* Stream Header */
    char *header;
    int headerSize;

    /* Network I/O stuff */
    int dataSocket;
    int commandSocket;

    /* Video Server Stuff */
    char *serverIP;
    char *serverFilename;
    long int serverFileOffset;

    /* WWW Stuff */
    char *httpServer;
    int httpPort;
    char *urlPath;
    int wwwSocket;

    /* Random Access Table */
    long int *randomFileOffset;
    long int *randomFrameNumber;
    long int numFileOffsets;

    /* Graphical User Interface Handling  */
    
    int ackNetwork;               /* Ack. from network process */
    int ackVideo;                 /* Ack. from video process */  
    int ackAudio;                 /* Ack. from audio process */

    /* GUI STUFF */
    int           action;                      /* Forw.only or Forw./Rev. */
    pid_t         iopid;                       /* pid of sproc thread or 0 */
    pid_t         vidpid;
    pid_t         audpid;
    pid_t         uipid;
    long int      currFrame;
    int           curFrame;                   /* Curr. frame, at any instant */


    /* Graphical User Interface Handling  */


    int audFunc;
    int vidFunc;
    int ioFunc;

    
    int state;                    /* Current state of the player. */
    int dragBarPercent;           /* Percent dragged in the scroll bar */
    int ui_ready;

    /* Icon for video marks. */
    char *icon;

    /* cpu stuff */
    int io_cpu;
    int video_cpu;
    int audio_cpu;
    int ui_cpu;
    int total_cpu;
    int cpu_force_value;


    int ackToUI;

    /* buffer used for the status line at the bottom of the main window. */
    char *sl_buf;

    /* Video Marks */

    FILE *vm_file;
    int num_vm;
    int markPage;
    int v_marks_stat[20];
    VideoMark *v_mark[20];


} MpegPlay;
#endif

